"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.pdfViewer = void 0;
const path_1 = __importDefault(require("path"));
const fs_1 = require("fs");
const serve_static_1 = __importDefault(require("serve-static"));
const utils_1 = require("./utils");
function pdfViewer(options) {
    const buildDir = path_1.default.resolve((options === null || options === void 0 ? void 0 : options.build) || "./node_modules/pdfjs-viewer-build/viewer/");
    const viewerPath = path_1.default.join(buildDir, "index.html");
    const prefix = (options === null || options === void 0 ? void 0 : options.prefix) || "";
    let outDir;
    let indexPath;
    let viewerSource;
    return {
        name: "vite-plugin-pdfjs-viewer",
        configResolved(config) {
            indexPath = path_1.default.join(config.root, prefix, "index.html");
            outDir = config.build.outDir;
        },
        transformIndexHtml(html, ctx) {
            return __awaiter(this, void 0, void 0, function* () {
                if (ctx.path === `/${prefix}index.html`) {
                    if (!viewerSource)
                        viewerSource = yield fs_1.promises.readFile(viewerPath, { encoding: "utf8" });
                    let out = viewerSource;
                    const { head, body } = (0, utils_1.parsehtml)(html);
                    if (head)
                        out = (0, utils_1.injectString)(out, out.indexOf("</head>"), head);
                    if (body)
                        out = (0, utils_1.injectString)(out, out.indexOf("</body>"), body);
                    return out;
                }
                else {
                    return html;
                }
            });
        },
        configureServer(server) {
            return __awaiter(this, void 0, void 0, function* () {
                let index = prefix
                    ? yield fs_1.promises.access(indexPath).then(() => true, () => false)
                    : false;
                const route = server.config.base + prefix;
                const serve = (0, serve_static_1.default)(buildDir, Object.assign(Object.assign({}, options === null || options === void 0 ? void 0 : options.serve), { index }));
                server.middlewares.use(route, serve);
            });
        },
        closeBundle() {
            return __awaiter(this, void 0, void 0, function* () {
                yield (0, utils_1.copyFilesRecursive)(buildDir, outDir, utils_1.filterFile);
            });
        }
    };
}
exports.pdfViewer = pdfViewer;
exports.default = pdfViewer;
